package com.cpxt.web.controller.biz;

import java.util.List;
import javax.servlet.http.HttpServletResponse;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.cpxt.common.annotation.Log;
import com.cpxt.common.core.controller.BaseController;
import com.cpxt.common.core.domain.AjaxResult;
import com.cpxt.common.enums.BusinessType;
import com.cpxt.biz.domain.BizOrderSub;
import com.cpxt.biz.service.IBizOrderSubService;
import com.cpxt.common.utils.poi.ExcelUtil;
import com.cpxt.common.core.page.TableDataInfo;

/**
 * 订单子单Controller
 * 
 * @author YIN
 * @date 2024-12-16
 */
@RestController
@RequestMapping("/biz/sub")
public class BizOrderSubController extends BaseController
{
    @Autowired
    private IBizOrderSubService bizOrderSubService;

    /**
     * 查询订单子单列表
     */
    @PreAuthorize("@ss.hasPermi('biz:sub:list')")
    @GetMapping("/list")
    public TableDataInfo list(BizOrderSub bizOrderSub)
    {
        startPage();
        List<BizOrderSub> list = bizOrderSubService.selectBizOrderSubList(bizOrderSub);
        return getDataTable(list);
    }

    /**
     * 导出订单子单列表
     */
    @PreAuthorize("@ss.hasPermi('biz:sub:export')")
    @Log(title = "订单子单", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, BizOrderSub bizOrderSub)
    {
        List<BizOrderSub> list = bizOrderSubService.selectBizOrderSubList(bizOrderSub);
        ExcelUtil<BizOrderSub> util = new ExcelUtil<BizOrderSub>(BizOrderSub.class);
        util.exportExcel(response, list, "订单子单数据");
    }

    /**
     * 获取订单子单详细信息
     */
    @PreAuthorize("@ss.hasPermi('biz:sub:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return success(bizOrderSubService.selectBizOrderSubById(id));
    }

    /**
     * 新增订单子单
     */
    @PreAuthorize("@ss.hasPermi('biz:sub:add')")
    @Log(title = "订单子单", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody BizOrderSub bizOrderSub)
    {
        return toAjax(bizOrderSubService.insertBizOrderSub(bizOrderSub));
    }

    /**
     * 修改订单子单
     */
    @PreAuthorize("@ss.hasPermi('biz:sub:edit')")
    @Log(title = "订单子单", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody BizOrderSub bizOrderSub)
    {
        return toAjax(bizOrderSubService.updateBizOrderSub(bizOrderSub));
    }

    /**
     * 删除订单子单
     */
    @PreAuthorize("@ss.hasPermi('biz:sub:remove')")
    @Log(title = "订单子单", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(bizOrderSubService.deleteBizOrderSubByIds(ids));
    }
}
